aboutgitcodebugslistschat
path: root/udp.h
diff options
context:
space:
mode:
Diffstat (limited to 'udp.h')
-rw-r--r--udp.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/udp.h b/udp.h
index f3d5d6d..9976b62 100644
--- a/udp.h
+++ b/udp.h
@@ -43,12 +43,12 @@ union udp_epoll_ref {
/**
* udp_port_fwd - UDP specific port forwarding configuration
* @f: Generic forwarding configuration
* @rdelta: Reversed delta map to translate source ports on return packets
*/
-struct udp_port_fwd {
- struct port_fwd f;
+struct udp_fwd_ports {
+ struct fwd_ports f;
in_port_t rdelta[NUM_PORTS];
};
@@ -59,8 +59,8 @@ struct udp_port_fwd {
* @timer_run: Timestamp of most recent timer run
*/
struct udp_ctx {
- struct udp_port_fwd fwd_in;
- struct udp_port_fwd fwd_out;
+ struct udp_fwd_ports fwd_in;
+ struct udp_fwd_ports fwd_out;
struct timespec timer_run;
};
@@ -43,12 +43,12 @@ union udp_epoll_ref {
/**
- * udp_port_fwd - UDP specific port forwarding configuration
+ * udp_fwd_ports - UDP specific port forwarding configuration
* @f: Generic forwarding configuration
* @rdelta: Reversed delta map to translate source ports on return packets